@@ -9,11 +9,16 @@
 #ifndef PLASMA_NM_MOBILE_PROXY_MODEL_H
 #define PLASMA_NM_MOBILE_PROXY_MODEL_H
 
+#include "plasmanm_internal_export.h"
+
 #include <QSortFilterProxyModel>
 
-class Q_DECL_EXPORT MobileProxyModel : public QSortFilterProxyModel
+#include <qqmlregistration.h>
+
+class PLASMANM_INTERNAL_EXPORT MobileProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_PROPERTY(QAbstractItemModel *sourceModel READ sourceModel WRITE setSourceModel)
     Q_PROPERTY(bool showSavedMode READ showSavedMode WRITE setShowSavedMode NOTIFY showSavedModeChanged)
 public:
